Terminal UI
===========

.. versionchanged:: 0.6.0

   Refactored as a separate sub-package to match on par with the webui module.

.. versionchanged:: 0.5.0

   Refactored to support advanced terminal features like auto-completion.

.. seealso:: Check out the tutorial :ref:`cust-commands` about adding custom commands.

.. _monitor-cli:

``aiomonitor.termui.commands``
------------------------------

.. automodule:: aiomonitor.termui.commands
   :members:
   :undoc-members:

.. click:: aiomonitor.termui.commands:monitor_cli
   :prog: monitor_cli

``aiomonitor.termui.completion``
--------------------------------

You may inspect or modify the auto-completion helpers here.

.. automodule:: aiomonitor.termui.completion
   :members:
   :undoc-members:
